@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: monad-journal
-version: 0.7.1
-id: monad-journal-0.7.1-3a626be79c00f2598a70f93649878d8a
-key: monad_CwKG4iy0kceL1gjTufIfQ3
+version: 0.7.2
+id: monad-journal-0.7.2-c091c5b660af604791f6151c0857d72d
+key: monad_70S6xFjcl7gHqUrAoSkiaI
 license: BSD3
 maintainer: Dimitri Sabadie <dimitri.sabadie@gmail.com>
 homepage: http://github.com/phaazon/monad-journal
@@ -22,13 +22,13 @@ exposed-modules:
     Control.Monad.Journal Control.Monad.Journal.Class
     Control.Monad.Trans.Journal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.1
-hs-libraries: HSmonad-journal-0.7.1-CwKG4iy0kceL1gjTufIfQ3
+import-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/monad-journal-0.7.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/monad-journal-0.7.2
+hs-libraries: HSmonad-journal-0.7.2-70S6xFjcl7gHqUrAoSkiaI
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    either-4.4.1-034f73c037cf6acbd6a0e4686245d294
+    either-4.4.1.1-9b4e1ab30e64d0a7367f7fb822cda30c
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
